'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _h2xPluginJsx = require('h2x-plugin-jsx');

var _h2xPluginJsx2 = _interopRequireDefault(_h2xPluginJsx);

var _wrapIntoComponent = require('./transforms/wrapIntoComponent');

var _wrapIntoComponent2 = _interopRequireDefault(_wrapIntoComponent);

var _wrapIntoNativeComponent = require('./transforms/wrapIntoNativeComponent');

var _wrapIntoNativeComponent2 = _interopRequireDefault(_wrapIntoNativeComponent);

var _stripAttribute = require('./h2x/stripAttribute');

var _stripAttribute2 = _interopRequireDefault(_stripAttribute);

var _emSize = require('./h2x/emSize');

var _emSize2 = _interopRequireDefault(_emSize);

var _expandProps = require('./h2x/expandProps');

var _expandProps2 = _interopRequireDefault(_expandProps);

var _svgRef = require('./h2x/svgRef');

var _svgRef2 = _interopRequireDefault(_svgRef);

var _replaceAttrValue = require('./h2x/replaceAttrValue');

var _replaceAttrValue2 = _interopRequireDefault(_replaceAttrValue);

var _removeComments = require('./h2x/removeComments');

var _removeComments2 = _interopRequireDefault(_removeComments);

var _removeStyle = require('./h2x/removeStyle');

var _removeStyle2 = _interopRequireDefault(_removeStyle);

var _toReactNative = require('./h2x/toReactNative');

var _toReactNative2 = _interopRequireDefault(_toReactNative);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultConfig = {
  ref: false,
  svgo: true,
  prettier: true,
  native: false,
  icon: false,
  viewBox: true,
  replaceAttrValues: [],
  expandProps: true,
  title: true,
  ids: false,
  precision: 3, // default to svgo
  semi: undefined, // default to prettier
  singleQuote: undefined, // default to prettier
  tabWidth: undefined, // default to prettier
  useTabs: undefined, // default to prettier
  trailingComma: undefined, // default to prettier
  bracketSpacing: undefined, // default to prettier
  jsxBracketSameLine: undefined, // default to prettier
  template: _wrapIntoComponent2.default
};

function configToOptions(config = {}) {
  if (!config.template && config.native) config.template = _wrapIntoNativeComponent2.default;
  config = _extends({}, defaultConfig, config);

  function getH2xPlugins() {
    const plugins = [_h2xPluginJsx2.default, (0, _stripAttribute2.default)('xmlns'), _removeComments2.default, _removeStyle2.default];
    if (config.icon) plugins.push(_emSize2.default);
    config.replaceAttrValues.forEach(([oldValue, newValue]) => {
      plugins.push((0, _replaceAttrValue2.default)(oldValue, newValue));
    });
    if (config.ref) plugins.push(_svgRef2.default);
    if (config.expandProps) plugins.push(_expandProps2.default);
    if (config.native) plugins.push(_toReactNative2.default);

    return plugins;
  }

  function getSvgoConfig() {
    const plugins = [];
    const svgoConfig = { plugins };
    if (!config.title || config.icon) plugins.push({ removeTitle: {} });else if (config.title) plugins.push({ removeTitle: false });
    if (config.viewBox) plugins.push({ removeViewBox: false });
    if (config.ids) plugins.push({ cleanupIDs: { remove: false } });
    if (config.precision === 'number') svgoConfig.floatPrecision = Number(svgoConfig.precision);
    return svgoConfig;
  }

  function getPrettierConfig() {
    return {
      semi: config.semi,
      singleQuote: config.singleQuote,
      tabWidth: config.tabWidth,
      useTabs: config.useTabs,
      trailingComma: config.trailingComma,
      bracketSpacing: config.bracketSpacing,
      jsxBracketSameLine: config.jsxBracketSameLine
    };
  }

  return {
    svgo: config.svgo ? getSvgoConfig() : null,
    h2x: {
      plugins: getH2xPlugins()
    },
    prettier: config.prettier ? getPrettierConfig() : null,
    template: config.template(config)
  };
}

exports.default = configToOptions;